@@ -1,7 +1,7 @@
 model.cont.het.cor <- function(prior.type="invwishart",rank.prob=TRUE){
 if(prior.type=="invwishart" & rank.prob){
-cat(
-"model{
+modelstring<-"
+model{
  for(i in 1:len){
   mean[i]~dnorm(theta[i],n[i]/pow(sd[i],2))
   theta[i]<-mu[t[i]]+vi[s[i],t[i]]
@@ -24,12 +24,13 @@ cat(
  for(i in 1:ntrt){
   rank.prob[1:ntrt,i]<-equals(rk[],i)
  }
-}",file="tempmodel.txt")
+}
+"
 }
 
 if(prior.type=="invwishart" & !rank.prob){
-cat(
-"model{
+modelstring<-"
+model{
  for(i in 1:len){
   mean[i]~dnorm(theta[i],n[i]/pow(sd[i],2))
   theta[i]<-mu[t[i]]+vi[s[i],t[i]]
@@ -48,10 +49,13 @@ cat(
  }
  invT[1:ntrt,1:ntrt]<-inverse(T[,])
  T[1:ntrt,1:ntrt]~dwish(I[1:ntrt,1:ntrt],ntrt+1)
-}",file="tempmodel.txt")
+}
+"
 }
 
 if(!is.element(prior.type,c("invwishart"))){
-  stop("specified prior type are wrong.")
+  stop("specified prior type is wrong.")
 }
+
+return(modelstring)
 }
\ No newline at end of file
