@@ -21,7 +21,14 @@ function(s.id,t.id,event.n,total.n,followup,data,trtname,param=c("lograte","logr
   if(!is.element(model,c("hom_eqcor","het_eqcor","het_cor"))) stop("model should be specified as \"hom_eqcor\", \"het_eqcor\", or \"het_cor\".")
 
   if(any(is.na(s.id))|any(is.na(t.id))|any(is.na(event.n))|any(is.na(total.n))|any(is.na(followup))){
-    stop("NA is not allowed in the input data set;\n  the rows containing NA should be removed.")
+    dat<-cbind(s.id,t.id,event.n,total.n,followup)
+    s.id<-s.id[complete.cases(dat)]
+    t.id<-t.id[complete.cases(dat)]
+    event.n<-event.n[complete.cases(dat)]
+    total.n<-total.n[complete.cases(dat)]
+    followup<-followup[complete.cases(dat)]
+    cat("NA is not allowed in the input data set;\n")
+    cat("the rows containing NA are removed.\n")
   }
 
   ## make ids continuous
